import 'package:niralakam_widget/model/card_horizontal_first_with_sub_widget_model.dart';
import 'package:niralakam_widget/theme/niralakam-share-theme.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:niralakam_widget/widget/sub_header_widget/sub_header_widget.dart';

class CardHorizontalFirstWithSubInfoWidget extends StatelessWidget {
  const CardHorizontalFirstWithSubInfoWidget({
    Key key,
    this.data,
    this.animationController,
    this.animation,
  }) : super(key: key);

  final Detail data;
  final AnimationController animationController;
  final Animation<dynamic> animation;

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: Transform(
            transform: NiralakamSharedTheme.subTransform(animation),
            child: InkWell(
              splashColor: Colors.transparent,
              child: SizedBox(
                width: 280,
                child: Stack(
                  children: <Widget>[
                    Container(
                      child: Row(
                        children: <Widget>[
                          const SizedBox(
                            width: 48,
                          ),
                          Expanded(
                            child: Container(
                              decoration: BoxDecoration(
                                color: NiralakamSharedTheme
                                    .lightGreyWithOpacityMedium,
                                borderRadius:
                                    NiralakamSharedTheme.borderRadiusMedium,
                              ),
                              child: Row(
                                children: <Widget>[
                                  const SizedBox(
                                    width: 48 + 24.0,
                                  ),
                                  Expanded(
                                    child: Container(
                                      child: Column(
                                        children: <Widget>[
                                          Padding(
                                            padding:
                                                const EdgeInsets.only(top: 16),
                                            child: SubHeaderWidget(
                                              titleTxt: data.key,
                                              animation: NiralakamSharedTheme
                                                  .animationOption(
                                                      animationController),
                                              animationController:
                                                  animationController,
                                            ),
                                          ),
                                          const Expanded(
                                            child: SizedBox(),
                                          ),
                                          Padding(
                                            padding: const EdgeInsets.only(
                                                right: 16, bottom: 8),
                                            child: Row(
                                              mainAxisAlignment:
                                                  MainAxisAlignment
                                                      .spaceBetween,
                                              crossAxisAlignment:
                                                  CrossAxisAlignment.center,
                                              children: <Widget>[
                                                Expanded(
                                                  child: Text(
                                                    "",
                                                    textAlign: TextAlign.left,
                                                    style: NiralakamSharedTheme
                                                        .textStyleSmall,
                                                  ),
                                                )
                                              ],
                                            ),
                                          ),
                                          Padding(
                                            padding: EdgeInsets.only(
                                                bottom: 16, right: 16),
                                            child: Row(
                                              mainAxisAlignment:
                                                  MainAxisAlignment
                                                      .spaceBetween,
                                              crossAxisAlignment:
                                                  CrossAxisAlignment.start,
                                              children: <Widget>[
                                                Text(
                                                  data.value,
                                                  textAlign: TextAlign.left,
                                                  style: MediaQuery.of(context)
                                                              .size
                                                              .width >=
                                                          375
                                                      ? NiralakamSharedTheme
                                                          .textStyleMedium
                                                      : NiralakamSharedTheme
                                                          .textStyleMedium,
                                                ),
                                                Container(
                                                  decoration: BoxDecoration(
                                                    color: NiralakamSharedTheme
                                                        .primaryColor,
                                                    borderRadius:
                                                        BorderRadius.all(
                                                            Radius.circular(
                                                                8.0)),
                                                  ),
                                                  child: Padding(
                                                    padding: EdgeInsets.all(5),
                                                    child: Text(
                                                      'more',
                                                      style: NiralakamSharedTheme
                                                          .textStyleExtraSmallWhite,
                                                    ),
                                                  ),
                                                )
                                              ],
                                            ),
                                          ),
                                        ],
                                      ),
                                    ),
                                  ),
                                ],
                              ),
                            ),
                          )
                        ],
                      ),
                    ),
                    Container(
                      child: Padding(
                        padding: EdgeInsets.only(top: 24, bottom: 24, left: 16),
                        child: Row(
                          children: <Widget>[
                            ClipRRect(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(16.0)),
                              child: Container(
                                padding: const EdgeInsets.only(
                                    top: 16, bottom: 16, right: 16, left: 16),
                                color:
                                    NiralakamSharedTheme.grey.withOpacity(0.2),
                                child: AspectRatio(
                                  aspectRatio: 1.0,
                                  child: CachedNetworkImage(
                                    imageUrl: data.src,
                                    progressIndicatorBuilder: (context, url,
                                            downloadProgress) =>
                                        CircularProgressIndicator(
                                            value: downloadProgress.progress),
                                    errorWidget: (context, url, error) =>
                                        Icon(Icons.error),
                                  ),
                                  // child: Image.network(data.src),
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              // onTap: () {
              //   Navigator.push<dynamic>(
              //     context,
              //     MaterialPageRoute<dynamic>(
              //       builder: (BuildContext context) =>
              //           new WeaponDetailScreen(data: data),
              //     ),
              //   );
              // },
            ),
          ),
        );
      },
    );
  }
}
